@@ -78,6 +78,8 @@ TEMPLATE_CONTEXT_PROCESSORS = [
     'django.core.context_processors.tz',
     'django.contrib.messages.context_processors.messages',
     'coop.context_processors.current_site',
+    'preferences.context_processors.preferences_cp',
+
 ]
 
 ROOT_URLCONF = 'coop_local.urls'
@@ -136,6 +138,7 @@ INSTALLED_APPS = [
     'autoslug',
     'slugify',
     'forms_builder.forms',
+    'preferences',
 
     # WebID
     #'django_webid.provider',
@@ -199,7 +202,7 @@ COOP_CMS_ARTICLE_LOGO_SIZE = '600'
 COOP_CMS_NAVTREE_CLASS = 'coop_local.NavTree'
 
 # You need to declare the app here to be able to select models from navigable types in coop-cms
-COOP_CMS_CONTENT_APPS = ('coop_local', 'coop_tag', 'coop_geo', 'coop_cms')
+COOP_CMS_CONTENT_APPS = ('coop_local', 'coop_tag', 'coop_geo', 'coop_cms', 'forms')
 
 DJALOHA_LINK_MODELS = (
         'coop_local.Article',
