@@ -5,7 +5,7 @@ from coop_local.models import SitePrefs
 from coop.utils.autocomplete_admin import FkAutocompleteAdmin, InlineAutocompleteAdmin
 
 
-class BaseSitePrefsAdmin(PreferencesAdmin, FkAutocompleteAdmin):
+class SitePrefsAdmin(PreferencesAdmin, FkAutocompleteAdmin):
     related_search_fields = {'main_organization': ('title', 'subtitle', 'acronym'), }
 
-admin.site.register(Preferences, BaseSitePrefsAdmin)
+admin.site.register(SitePrefs, SitePrefsAdmin)
